Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ProjectListResponse ¶
type ProjectListResponse struct {
Items []ProjectResponse `json:"items"`
Total int `json:"total" example:"1"`
}
ProjectListResponse represents the API response for a list of projects.
func NewProjectListResponse ¶
func NewProjectListResponse(items []projects.Project, total int) ProjectListResponse
type ProjectRequest ¶
type ProjectRequest struct {
Name string `json:"name" validate:"required" example:"Backend Service"`
RepoURL string `json:"repo_url" validate:"required,url" example:"https://bitbucket.org/company/backend"`
}
ProjectRequest represents the request body for creating a new project.
type ProjectResponse ¶
ProjectResponse represents the API response for a single project.
func NewProjectResponse ¶
func NewProjectResponse(p *projects.Project) ProjectResponse
type ProjectUpdateRequest ¶
type ProjectUpdateRequest struct {
Name *string `json:"name,omitempty" validate:"omitempty" example:"Backend Service"`
RepoURL *string `json:"repo_url,omitempty" validate:"omitempty,url" example:"https://bitbucket.org/company/backend"`
}
ProjectUpdateRequest represents the request body for updating a project. All fields are optional to support partial updates.
Click to show internal directories.
Click to hide internal directories.